import {
  select,
  csv,
  axisLeft,
  axisBottom,
  scaleOrdinal,
  format,
  schemeSpectral,
  scale,
  interpolateViridis
} from 'd3';

import { loadAndProcessData } from './loadAndProcessData';
import { scatterPlot } from './scatterPlot';
import { colorLegend } from './colorLegend';


 
const svg = select('svg');
const scatterPlotG = svg.append('g');
const colorLegendG = svg.append('g')
    .attr('transform',`translate(880,250)`)
	.attr('text',"bskfjdbf");

const width = +svg.attr('width'); 
const height = +svg.attr('height');

const title = 'Cars: Horsepower vs. Weight';
const xValue = d => d.horsepower;
const xAxisLabel = 'Horsepower';
const yValue = d => d.weight;
const circleRadius = 6;
const yAxisLabel = 'Weight';
const legendLabel = "Cylinders"
  
const margin = { top: 60, right: 130, bottom: 88, left: 150 };
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const colorScale = scaleOrdinal();
const colorValue = d => d.cylinders;
let selectedColorValue;
let data;
 
const onClick = d => {
  selectedColorValue = d;
  render();  
}

loadAndProcessData()
  .then(d => {
    data = d
    console.log("ddd")
    console.log(d)
    console.log("2222")
    render() 
  });

const render = () => { 
  colorScale
    .domain(data.map(colorValue))
    .domain(colorScale.domain().sort().reverse());
  
  const n = colorScale.domain().length;

  colorScale.range(colorScale.domain().map((d, i) =>
    interpolateViridis(i/(n-1))
  ));
  
  scatterPlotG.call(scatterPlot,{
    data,
    width,
    height,
    margin,
    title,
    xValue,
    xAxisLabel,
    yValue,
    yAxisLabel, 
    circleRadius,
    colorValue,
    colorScale,
    selectedColorValue,
    innerWidth,
    innerHeight
  });
  
  colorLegendG.call(colorLegend,{
    colorScale,
    circleRadius: 10,
    spacing: 26,
    textOffset: 12,
    backgroundRectWidth:130,
    onClick,
    selectedColorValue
  });
};



